@@ -1,5 +1,4 @@
 use super::super::{CountOfPerSize, FileDbParams};
-use super::dat;
 use super::semtype::*;
 use super::vfile::VarFile;
 use std::cell::RefCell;
@@ -70,16 +69,22 @@ impl IdxFile {
         //
         Ok(Self(Rc::new(RefCell::new(file_nc))))
     }
+    pub fn flush(&self) -> Result<()> {
+        let mut locked = self.0.borrow_mut();
+        #[cfg(feature = "node_cache")]
+        idx_node_cache_flush(&mut locked)?;
+        locked.0.flush()
+    }
     pub fn sync_all(&self) -> Result<()> {
         let mut locked = self.0.borrow_mut();
         #[cfg(feature = "node_cache")]
-        idx_cache_flush_clear(&mut locked)?;
+        idx_node_cache_flush_clear(&mut locked)?;
         locked.0.sync_all()
     }
     pub fn sync_data(&self) -> Result<()> {
         let mut locked = self.0.borrow_mut();
         #[cfg(feature = "node_cache")]
-        idx_cache_flush_clear(&mut locked)?;
+        idx_node_cache_flush_clear(&mut locked)?;
         locked.0.sync_data()
     }
     #[cfg(feature = "buf_stats")]
@@ -208,23 +213,26 @@ impl IdxFile {
         Ok(1 + mx)
     }
     //
-    pub fn is_mst_valid(&self, node: &IdxNode, dat_file: dat::DatFile) -> Result<bool> {
+    pub fn is_mst_valid<KT>(&self, node: &IdxNode, dbxxx: &FileDbXxxInner<KT>) -> Result<bool>
+    where
+        KT: FileDbXxxInnerKT + std::fmt::Display + std::default::Default + std::cmp::PartialOrd,
+    {
         if node.keys.is_empty() {
             return Ok(true);
         }
         let record_offset = node.keys[0];
         let key_string = if !record_offset.is_zero() {
-            String::from_utf8_lossy(&dat_file.read_record_key(record_offset)?).to_string()
+            dbxxx.load_key_string_no_cache(record_offset)?
         } else {
-            String::new()
+            Default::default()
         };
         let node_offset = node.downs[0];
         if !node_offset.is_zero() {
             let node1 = self.read_node(node_offset)?;
-            if !self.is_small(&key_string, &node1, dat_file.clone())? {
+            if !self.is_small(&key_string, &node1, dbxxx)? {
                 return Ok(false);
             }
-            if !self.is_mst_valid(&node1, dat_file.clone())? {
+            if !self.is_mst_valid(&node1, dbxxx)? {
                 return Ok(false);
             }
         }
@@ -237,24 +245,24 @@ impl IdxFile {
                 break;
             }
             let key_string1 = if !key_offset1.is_zero() {
-                String::from_utf8_lossy(&dat_file.read_record_key(key_offset1)?).to_string()
+                dbxxx.load_key_string_no_cache(key_offset1)?
             } else {
-                String::new()
+                Default::default()
             };
             let key_string2 = if !key_offset2.is_zero() {
-                String::from_utf8_lossy(&dat_file.read_record_key(key_offset2)?).to_string()
+                dbxxx.load_key_string_no_cache(key_offset2)?
             } else {
-                String::new()
+                Default::default()
             };
             if key_string1 >= key_string2 {
                 return Ok(false);
             }
             if !node_offset.is_zero() {
                 let node1 = self.read_node(node_offset)?;
-                if !self.is_between(&key_string1, &key_string2, &node1, dat_file.clone())? {
+                if !self.is_between(&key_string1, &key_string2, &node1, dbxxx)? {
                     return Ok(false);
                 }
-                if !self.is_mst_valid(&node1, dat_file.clone())? {
+                if !self.is_mst_valid(&node1, dbxxx)? {
                     return Ok(false);
                 }
             }
@@ -265,13 +273,12 @@ impl IdxFile {
         if !node_offset.is_zero() {
             let node1 = self.read_node(node_offset)?;
             if !record_offset.is_zero() {
-                let key_string =
-                    String::from_utf8_lossy(&dat_file.read_record_key(record_offset)?).to_string();
-                if !self.is_large(&key_string, &node1, dat_file.clone())? {
+                let key_string = dbxxx.load_key_string_no_cache(record_offset)?;
+                if !self.is_large(&key_string, &node1, dbxxx)? {
                     return Ok(false);
                 }
             }
-            if !self.is_mst_valid(&node1, dat_file)? {
+            if !self.is_mst_valid(&node1, dbxxx)? {
                 return Ok(false);
             }
         }
@@ -279,20 +286,22 @@ impl IdxFile {
         Ok(true)
     }
     //
-    fn is_small(&self, key: &str, node: &IdxNode, dat_file: dat::DatFile) -> Result<bool> {
+    fn is_small<KT>(&self, key: &KT, node: &IdxNode, dbxxx: &FileDbXxxInner<KT>) -> Result<bool>
+    where
+        KT: FileDbXxxInnerKT + std::fmt::Display + std::default::Default + std::cmp::PartialOrd,
+    {
         for i in 0..node.keys.len() {
             let node_offset = node.downs[i];
             if !node_offset.is_zero() {
                 let node1 = self.read_node(node_offset)?;
-                if !self.is_small(key, &node1, dat_file.clone())? {
+                if !self.is_small(key, &node1, dbxxx)? {
                     return Ok(false);
                 }
             }
             let record_offset = node.keys[i];
             if !record_offset.is_zero() {
-                let ket_string1 =
-                    String::from_utf8_lossy(&dat_file.read_record_key(record_offset)?).to_string();
-                if key <= &ket_string1 {
+                let key_string1 = dbxxx.load_key_string_no_cache(record_offset)?;
+                if key <= &key_string1 {
                     return Ok(false);
                 }
             }
@@ -301,33 +310,34 @@ impl IdxFile {
         let node_offset = node.downs[node.keys.len()];
         if !node_offset.is_zero() {
             let node1 = self.read_node(node_offset)?;
-            if !self.is_small(key, &node1, dat_file)? {
+            if !self.is_small(key, &node1, dbxxx)? {
                 return Ok(false);
             }
         }
         //
         Ok(true)
     }
-    fn is_between(
+    fn is_between<KT>(
         &self,
-        key1: &str,
-        key2: &str,
+        key1: &KT,
+        key2: &KT,
         node: &IdxNode,
-        dat_file: dat::DatFile,
-    ) -> Result<bool> {
+        dbxxx: &FileDbXxxInner<KT>,
+    ) -> Result<bool>
+    where
+        KT: FileDbXxxInnerKT + std::fmt::Display + std::default::Default + std::cmp::PartialOrd,
+    {
         for i in 0..node.keys.len() {
             let node_offset = node.downs[i];
             if !node_offset.is_zero() {
                 let node1 = self.read_node(node_offset)?;
-                if !self.is_between(key1, key2, &node1, dat_file.clone())? {
+                if !self.is_between(key1, key2, &node1, dbxxx)? {
                     return Ok(false);
                 }
             }
             let record_offset11 = node.keys[i];
             if !record_offset11.is_zero() {
-                let ket_string11 =
-                    String::from_utf8_lossy(&dat_file.read_record_key(record_offset11)?)
-                        .to_string();
+                let ket_string11 = dbxxx.load_key_string_no_cache(record_offset11)?;
                 if key1 >= &ket_string11 {
                     return Ok(false);
                 }
@@ -340,26 +350,28 @@ impl IdxFile {
         let node_offset = node.downs[node.keys.len()];
         if !node_offset.is_zero() {
             let node1 = self.read_node(node_offset)?;
-            if !self.is_between(key1, key2, &node1, dat_file)? {
+            if !self.is_between(key1, key2, &node1, dbxxx)? {
                 return Ok(false);
             }
         }
         //
         Ok(true)
     }
-    fn is_large(&self, key: &str, node: &IdxNode, dat_file: dat::DatFile) -> Result<bool> {
+    fn is_large<KT>(&self, key: &KT, node: &IdxNode, dbxxx: &FileDbXxxInner<KT>) -> Result<bool>
+    where
+        KT: FileDbXxxInnerKT + std::fmt::Display + std::default::Default + std::cmp::PartialOrd,
+    {
         for i in 0..node.keys.len() {
             let node_offset = node.downs[i];
             if !node_offset.is_zero() {
                 let node1 = self.read_node(node_offset)?;
-                if !self.is_large(key, &node1, dat_file.clone())? {
+                if !self.is_large(key, &node1, dbxxx)? {
                     return Ok(false);
                 }
             }
             let record_offset = node.keys[i];
             if !record_offset.is_zero() {
-                let ket_string1 =
-                    String::from_utf8_lossy(&dat_file.read_record_key(record_offset)?).to_string();
+                let ket_string1 = dbxxx.load_key_string_no_cache(record_offset)?;
                 if key >= &ket_string1 {
                     return Ok(false);
                 }
@@ -369,7 +381,7 @@ impl IdxFile {
         let node_offset = node.downs[node.keys.len()];
         if !node_offset.is_zero() {
             let node1 = self.read_node(node_offset)?;
-            if !self.is_large(key, &node1, dat_file)? {
+            if !self.is_large(key, &node1, dbxxx)? {
                 return Ok(false);
             }
         }
@@ -741,7 +753,7 @@ pub const NODE_SLOTS_MAX: u16 = 15;
 #[cfg(feature = "vf_u64u64")]
 pub const NODE_SLOTS_MAX: u16 = 7;
 #[cfg(feature = "vf_vu64")]
-pub const NODE_SLOTS_MAX: u16 = 13;
+pub const NODE_SLOTS_MAX: u16 = 7 * 2 - 1;
 pub const NODE_SLOTS_MAX_HALF: u16 = (NODE_SLOTS_MAX + 1) / 2;
 
 #[derive(Debug, Default, Clone)]
@@ -815,7 +827,13 @@ impl IdxNode {
 }
 
 #[cfg(feature = "node_cache")]
-fn idx_cache_flush_clear(file_nc: &mut VarFileNodeCache) -> Result<()> {
+fn idx_node_cache_flush(file_nc: &mut VarFileNodeCache) -> Result<()> {
+    file_nc.1.flush(&mut file_nc.0)?;
+    Ok(())
+}
+
+#[cfg(feature = "node_cache")]
+fn idx_node_cache_flush_clear(file_nc: &mut VarFileNodeCache) -> Result<()> {
     file_nc.1.clear(&mut file_nc.0)?;
     Ok(())
 }
@@ -841,111 +859,6 @@ fn idx_delete_node(file_nc: &mut VarFileNodeCache, node: IdxNode) -> Result<Node
     Ok(old_node_size)
 }
 
-/*
-fn idx_serialize_to_buf(node: &IdxNode) -> Result<Vec<u8>> {
-    let mut buff_cursor = VarCursor::with_capacity(9 * (2 * NODE_SLOTS_MAX as usize - 1));
-    //
-    let keys_count = node.keys.len() as u16;
-    buff_cursor.write_keys_count(KeysCount::new(keys_count))?;
-    //
-    for i in 0..(keys_count as usize) {
-        debug_assert!(!node.keys[i].is_zero());
-        let offset = node.keys[i];
-        buff_cursor.write_record_offset(offset)?;
-    }
-    for i in 0..((keys_count as usize) + 1) {
-        let offset = if i < node.downs.len() {
-            node.downs[i]
-        } else {
-            NodeOffset::new(0)
-        };
-        buff_cursor.write_node_offset(offset)?;
-    }
-    //
-    Ok(buff_cursor.into_inner())
-}
-
-fn idx_write_node(
-    file_nc: &mut VarFileNodeCache,
-    mut node: IdxNode,
-    is_new: bool,
-) -> Result<IdxNode> {
-    debug_assert!(!node.offset.is_zero());
-    //
-    let mut buf_vec = idx_serialize_to_buf(&node)?;
-    let buf_ref = &mut buf_vec;
-    let buf_len = buf_ref.len();
-    //
-    #[cfg(any(feature = "vf_u32u32", feature = "vf_u64u64"))]
-    let encoded_len = 4;
-    #[cfg(feature = "vf_vu64")]
-    let encoded_len = vu64::encoded_len(buf_len as u64);
-    //
-    let new_node_size = NodeSize::new(buf_len as u32 + encoded_len as u32);
-    let new_node_size = node_size_roudup(new_node_size);
-    //
-    if !is_new {
-        #[cfg(not(feature = "node_cache"))]
-        let old_node_size = {
-            let _ = file_nc.0.seek_from_start(node.offset)?;
-            file_nc.0.read_node_size()?
-        };
-        #[cfg(feature = "node_cache")]
-        let old_node_size = {
-            if let Some(node_size) = file_nc.1.get_node_size(&node.offset) {
-                node_size
-            } else {
-                let _ = file_nc.0.seek_from_start(node.offset)?;
-                file_nc.0.read_node_size()?
-            }
-        };
-        if new_node_size <= old_node_size {
-            // over writes.
-            #[cfg(not(feature = "node_cache"))]
-            {
-                let _ = file_nc.0.seek_from_start(node.offset)?;
-                file_nc.0.write_node_size(old_node_size)?;
-                file_nc.0.write_all(buf_ref)?;
-                return Ok(node);
-            }
-            #[cfg(feature = "node_cache")]
-            {
-                let node =
-                    file_nc
-                        .1
-                        .put(&mut file_nc.0, node, old_node_size, buf_ref.clone(), true)?;
-                return Ok(node);
-            }
-        } else {
-            // delete old and add new
-            #[cfg(feature = "node_cache")]
-            file_nc.1.delete(&node.offset);
-            // old
-            idx_file_push_free_list(&mut file_nc.0, node.offset, old_node_size)?;
-        }
-    }
-    // add new.
-    {
-        let free_node_offset = idx_file_pop_free_list(&mut file_nc.0, new_node_size)?;
-        let new_node_offset = if !free_node_offset.is_zero() {
-            let _ = file_nc.0.seek_from_start(free_node_offset)?;
-            let node_size = file_nc.0.read_node_size()?;
-            file_nc.0.write_node_clear(free_node_offset, node_size)?;
-            free_node_offset
-        } else {
-            let _ = file_nc.0.seek(SeekFrom::End(0))?;
-            let node_offset = NodeOffset::new(file_nc.0.stream_position()?);
-            file_nc.0.write_node_clear(node_offset, new_node_size)?;
-            node_offset
-        };
-        file_nc.0.write_all_small(buf_ref)?;
-        node.offset = new_node_offset;
-    }
-    //
-    Ok(node)
-}
-*/
-
 fn idx_write_node(
     file_nc: &mut VarFileNodeCache,
     mut node: IdxNode,
@@ -1074,15 +987,15 @@ fn idx_encoded_node_size(node: &IdxNode) -> usize {
 }
 
 pub(crate) fn idx_write_node_one(file: &mut VarFile, node: &IdxNode) -> Result<()> {
-    let keys_count = node.keys.len() as u16;
-    file.write_keys_count(KeysCount::new(keys_count))?;
+    let keys_count = node.keys.len();
+    file.write_keys_count(KeysCount::new(keys_count.try_into().unwrap()))?;
     //
-    for i in 0..(keys_count as usize) {
+    for i in 0..keys_count {
         debug_assert!(!node.keys[i].is_zero());
         let offset = node.keys[i];
         file.write_record_offset(offset)?;
     }
-    for i in 0..((keys_count as usize) + 1) {
+    for i in 0..(keys_count + 1) {
         let offset = if i < node.downs.len() {
             node.downs[i]
         } else {
@@ -1134,20 +1047,6 @@ fn idx_read_node(file_nc: &mut VarFileNodeCache, offset: NodeOffset) -> Result<I
     let _ = file_nc.0.seek_from_start(offset)?;
     let node_size = file_nc.0.read_node_size()?;
     debug_assert!(!node_size.is_zero());
-    /*
-    let node_size_usize: usize = node_size.try_into().unwrap();
-    //
-    #[cfg(any(feature = "vf_u32u32", feature = "vf_u64u64"))]
-    let encoded_len = 4 as usize;
-    #[cfg(feature = "vf_vu64")]
-    let encoded_len = vu64::encoded_len(node_size_usize as u64) as usize;
-    //
-    let buf = {
-        let mut vec = vec![0u8; node_size_usize - encoded_len];
-        file_nc.0.read_exact(&mut vec)?;
-        vec
-    };
-    */
     //
     let _ = file_nc.0.seek_from_start(offset)?;
     let node_size = file_nc.0.read_node_size()?;
@@ -1383,9 +1282,7 @@ used node:
 +--------+-------+-------------+-----------------------------------+
 | offset | bytes | name        | comment                           |
 +--------+-------+-------------+-----------------------------------+
-| 0      | 1..5  | node size   | size in bytes of this node: u32   |
-| 0      | 1     | size        | size in bytes of this node        |
-|        |       |             | (must be <= 0x7F)                 |
+| 0      | 1..5  | node size   | size in bytes of this node: vu32  |
 | 1      | 1     | key-count   | count of keys                     |
 | 2      | 1..9  | key1        | offset of key-value               |
 |        |       | ...         |                                   |
@@ -1403,8 +1300,6 @@ free node:
 | offset | bytes | name        | comment                           |
 +--------+-------+-------------+-----------------------------------+
 | 0      | 1..5  | node size   | size in bytes of this node: u32   |
-| 0      | 1     | size        | size in bytes of this node        |
-|        |       |             | (bit or 0x80)                     |
 | --     | 1     | keys-count  | always zero                       |
 | --     | 8     | next        | next free record offset           |
 | --     | --    | reserve     | reserved free space               |
