@@ -21,7 +21,7 @@ fn _test_a1() {
     #[rustfmt::skip]
     _test_db_map(
         TestC { max_cnt: 1_000, f_get: false, f_delete: false, f_repeat: 1 },
-        CheckC { check: true, ..Default::default() },
+        CheckC { check: true, f_mst: true, ..Default::default() },
         |i: usize| { format!("key{:01}", i) },
         |i: usize| { format!("value{:01}", i) },
     );
@@ -499,7 +499,7 @@ where
         let instant_per_op = (instant_ed - instant_st) / test_cnf.max_cnt.try_into().unwrap();
         println!("finish put: {:?}/op", instant_per_op);
         //
-        db_map.sync_data().unwrap();
+        db_map.flush().unwrap();
         //
         if check_cnf.check {
             _print_check_db_map(&db_map, check_cnf);
@@ -532,7 +532,7 @@ where
             let instant_per_op = (instant_ed - instant_st) / test_cnf.max_cnt.try_into().unwrap();
             println!("finish delete: {:?}/op", instant_per_op);
             //
-            db_map.sync_data().unwrap();
+            db_map.flush().unwrap();
             //
             if check_cnf.check {
                 _print_check_db_map(&db_map, check_cnf);
